rpms/kdelibs/devel kdelibs-4.3.75-parallel_devel.patch, NONE, 1.1 kdelibs-4.3.75-policykit-workaround.patch, NONE, 1.1 .cvsignore, 1.82, 1.83 kdelibs.spec, 1.536, 1.537 sources, 1.97, 1.98 kdelibs-4.1.72-policykit-workaround.patch, 1.1, NONE kdelibs-4.2.96-parallel_devel.patch, 1.1, NONE kdelibs-4.3.0-bookmarks.patch, 1.1, NONE kdelibs-4.3.1-ossl-1.x.patch, 1.1, NONE kdelibs-4.3.3-adFilteredBy.patch, 1.1, NONE kdelibs-4.3.3-fix-kdefakes-build.patch, 1.1, NONE

Ben Boeckel mathstuf at fedoraproject.org
Tue Nov 24 15:24:37 UTC 2009


Author: mathstuf

Update of /cvs/pkgs/rpms/kdelibs/devel
In directory cvs1.fedora.phx.redhat.com:/tmp/cvs-serv17045

Modified Files:
	.cvsignore kdelibs.spec sources 
Added Files:
	kdelibs-4.3.75-parallel_devel.patch 
	kdelibs-4.3.75-policykit-workaround.patch 
Removed Files:
	kdelibs-4.1.72-policykit-workaround.patch 
	kdelibs-4.2.96-parallel_devel.patch 
	kdelibs-4.3.0-bookmarks.patch kdelibs-4.3.1-ossl-1.x.patch 
	kdelibs-4.3.3-adFilteredBy.patch 
	kdelibs-4.3.3-fix-kdefakes-build.patch 
Log Message:
Update to 4.3.75

kdelibs-4.3.75-parallel_devel.patch:
 cmake/modules/FindKDE4Internal.cmake        |   34 ++++++++++++++--------------
 doc/api/doxygen-preprocess-kcfg.sh          |    4 +--
 kdecore/kconfig_compiler/CMakeLists.txt     |    6 ++--
 kdecore/kconfig_compiler/checkkcfg.pl       |    4 +--
 kdeui/tests/kconfig_compiler/CMakeLists.txt |    2 -
 kdewidgets/CMakeLists.txt                   |   12 ++++-----
 6 files changed, 32 insertions(+), 30 deletions(-)

--- NEW FILE kdelibs-4.3.75-parallel_devel.patch ---
diff -r -U5 kdelibs-4.3.75svn1048496/doc/api/doxygen-preprocess-kcfg.sh kdelibs-4.3.75svn1048496.parallel_devel/doc/api/doxygen-preprocess-kcfg.sh
--- kdelibs-4.3.75svn1048496/doc/api/doxygen-preprocess-kcfg.sh	2008-05-21 07:07:26.000000000 -0400
+++ kdelibs-4.3.75svn1048496.parallel_devel/doc/api/doxygen-preprocess-kcfg.sh	2009-11-23 10:33:58.000000000 -0500
@@ -1,12 +1,12 @@
 #
 # Generates and cleans KConfigXT source code during a API dox build
 #
 
-kcfg_compiler="`kde4-config --prefix`/bin/kconfig_compiler"
+kcfg_compiler="`kde4-config --prefix`/bin/kconfig_compiler4"
 if test -z "$kcfg_compiler"; then
-	echo "kconfig_compiler not found!"
+	echo "kconfig_compiler4 not found!"
 	exit 1;
 fi
 
 for i in `find . -maxdepth 1 -name "*.kcfgc"`; do
 	kcfg_file=`grep "^File=" $i | sed -e "s/File=//"`
diff -r -U5 kdelibs-4.3.75svn1048496/kdecore/kconfig_compiler/checkkcfg.pl kdelibs-4.3.75svn1048496.parallel_devel/kdecore/kconfig_compiler/checkkcfg.pl
--- kdelibs-4.3.75svn1048496/kdecore/kconfig_compiler/checkkcfg.pl	2008-05-21 07:09:13.000000000 -0400
+++ kdelibs-4.3.75svn1048496.parallel_devel/kdecore/kconfig_compiler/checkkcfg.pl	2009-11-23 10:33:58.000000000 -0500
@@ -13,16 +13,16 @@
 $file_h = "$filebase.h";
 $file_cpp = "$filebase.cpp";
 
 $kcfgc = $file . "c";
 
-$cmd = "./kconfig_compiler $file $kcfgc";
+$cmd = "./kconfig_compiler4 $file $kcfgc";
 
 #print "CMD $cmd\n";
 
 if ( system( $cmd ) != 0 ) {
-  print STDERR "Unable to run kconfig_compiler\n";
+  print STDERR "Unable to run kconfig_compiler4\n";
   exit 1;
 }
 
 checkfile( $file_h );
 checkfile( $file_cpp );
diff -r -U5 kdelibs-4.3.75svn1048496/kdecore/kconfig_compiler/CMakeLists.txt kdelibs-4.3.75svn1048496.parallel_devel/kdecore/kconfig_compiler/CMakeLists.txt
--- kdelibs-4.3.75svn1048496/kdecore/kconfig_compiler/CMakeLists.txt	2009-10-26 05:15:46.000000000 -0400
+++ kdelibs-4.3.75svn1048496.parallel_devel/kdecore/kconfig_compiler/CMakeLists.txt	2009-11-23 10:33:58.000000000 -0500
@@ -2,17 +2,17 @@
 ########### next target ###############
 
 set(kconfig_compiler_SRCS kconfig_compiler.cpp)
 
 
-kde4_add_executable(kconfig_compiler NOGUI ${kconfig_compiler_SRCS})
+kde4_add_executable(kconfig_compiler4 NOGUI ${kconfig_compiler_SRCS})
 
-target_link_libraries(kconfig_compiler  ${QT_QTCORE_LIBRARY} ${QT_QTXML_LIBRARY} )
+target_link_libraries(kconfig_compiler4  ${QT_QTCORE_LIBRARY} ${QT_QTXML_LIBRARY} )
 
 # "export" this target too so we can use the LOCATION property of the imported target in
 # FindKDE4Internal.cmake to get the full path to the installed executable instead of using FIND_PROGRAM(), Alex
-install(TARGETS kconfig_compiler EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS} )
+install(TARGETS kconfig_compiler4 EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS} )
 
 
 ########### install files ###############
 
 
diff -r -U5 kdelibs-4.3.75svn1048496/kdeui/tests/kconfig_compiler/CMakeLists.txt kdelibs-4.3.75svn1048496.parallel_devel/kdeui/tests/kconfig_compiler/CMakeLists.txt
--- kdelibs-4.3.75svn1048496/kdeui/tests/kconfig_compiler/CMakeLists.txt	2009-08-12 06:00:20.000000000 -0400
+++ kdelibs-4.3.75svn1048496.parallel_devel/kdeui/tests/kconfig_compiler/CMakeLists.txt	2009-11-23 10:33:58.000000000 -0500
@@ -7,11 +7,11 @@
 
 macro(GEN_KCFG_TEST_SOURCE _testName _srcs)
    add_custom_command(
       OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.cpp ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h
       COMMAND ${KDE4_KCFGC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc
-      DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc kconfig_compiler)
+      DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc kconfig_compiler4)
 
 #   set_source_files_properties(${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h PROPERTIES GENERATED TRUE)
    qt4_generate_moc(${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.moc )
 # do not run automoc on the generated file
    set_source_files_properties(${CMAKE_CURRENT_BINARY_DIR}/${_testName}.cpp PROPERTIES SKIP_AUTOMOC TRUE)
diff -r -U5 kdelibs-4.3.75svn1048496/kdewidgets/CMakeLists.txt kdelibs-4.3.75svn1048496.parallel_devel/kdewidgets/CMakeLists.txt
--- kdelibs-4.3.75svn1048496/kdewidgets/CMakeLists.txt	2009-09-23 15:23:44.000000000 -0400
+++ kdelibs-4.3.75svn1048496.parallel_devel/kdewidgets/CMakeLists.txt	2009-11-23 10:33:58.000000000 -0500
@@ -12,28 +12,28 @@
 ########### next target ###############
 
 set(makekdewidgets_SRCS makekdewidgets.cpp )
 
 
-kde4_add_executable(makekdewidgets NOGUI ${makekdewidgets_SRCS})
+kde4_add_executable(makekdewidgets4 NOGUI ${makekdewidgets_SRCS})
 
-target_link_libraries(makekdewidgets  ${KDE4_KDECORE_LIBS} )
+target_link_libraries(makekdewidgets4  ${KDE4_KDECORE_LIBS} )
 
 # "export" this target too so we can use the LOCATION property of the imported target in
 # FindKDE4Internal.cmake to get the full path to the installed executable instead of using FIND_PROGRAM(), Alex
-install(TARGETS makekdewidgets  EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS} )
+install(TARGETS makekdewidgets4  EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS} )
 
 
 ########### next target ###############
 
 
 # get the name of the generated wrapper script (which sets up LD_LIBRARY_PATH)
-get_target_property(MAKEKDEWIDGETS_EXECUTABLE makekdewidgets WRAPPER_SCRIPT)
+get_target_property(MAKEKDEWIDGETS_EXECUTABLE makekdewidgets4 WRAPPER_SCRIPT)
 
 add_custom_command(OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/kdewidgets.cpp
   COMMAND "${MAKEKDEWIDGETS_EXECUTABLE}" -o ${CMAKE_CURRENT_BINARY_DIR}/kdewidgets.cpp ${CMAKE_CURRENT_SOURCE_DIR}/kde.widgets
-  MAIN_DEPENDENCY kde.widgets DEPENDS makekdewidgets)
+  MAIN_DEPENDENCY kde.widgets DEPENDS makekdewidgets4)
 
 set(kdewidgets_PART_SRCS
    classpreviews.cpp
    ${CMAKE_CURRENT_BINARY_DIR}/kdewidgets.cpp
 )
@@ -64,11 +64,11 @@
      ${CMAKE_SOURCE_DIR}/kde3support/kdeui   
    )
 
    add_custom_command(OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/kde3supportwidgets.cpp
      COMMAND "${MAKEKDEWIDGETS_EXECUTABLE}" -o ${CMAKE_CURRENT_BINARY_DIR}/kde3supportwidgets.cpp ${CMAKE_CURRENT_SOURCE_DIR}/kde3support.widgets
-     MAIN_DEPENDENCY kde3support.widgets DEPENDS makekdewidgets)
+     MAIN_DEPENDENCY kde3support.widgets DEPENDS makekdewidgets4)
 
    set(kde3supportwidgets_PART_SRCS
       classpreviews.cpp
       ${CMAKE_CURRENT_BINARY_DIR}/kde3supportwidgets.cpp
    )

kdelibs-4.3.75-policykit-workaround.patch:
 halstorageaccess.cpp      |   70 ++++++++++++++++++++++++++++++++++++++++++++--
 halstorageaccess.cpp.orig |only
 halstorageaccess.h        |    3 +
 3 files changed, 71 insertions(+), 2 deletions(-)

--- NEW FILE kdelibs-4.3.75-policykit-workaround.patch ---
diff -r -U5 kdelibs-4.3.75svn1048496/solid/solid/backends/hal/halstorageaccess.cpp kdelibs-4.3.75svn1048496.polkit/solid/solid/backends/hal/halstorageaccess.cpp
--- kdelibs-4.3.75svn1048496/solid/solid/backends/hal/halstorageaccess.cpp	2009-08-12 06:00:18.000000000 -0400
+++ kdelibs-4.3.75svn1048496.polkit/solid/solid/backends/hal/halstorageaccess.cpp	2009-11-20 14:39:44.000000000 -0500
@@ -15,10 +15,12 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 
 */
 
+#include <config-prefix.h> // for LIBEXEC_INSTALL_DIR
+
 #include "halstorageaccess.h"
 
 #include "halfstabhandling.h"
 
 #include <QtCore/QLocale>
@@ -170,15 +172,25 @@
 
 void StorageAccess::slotDBusError(const QDBusError &error)
 {
     // TODO: Better error reporting here
     if (m_setupInProgress) {
+        if (error.name() == "org.freedesktop.Hal.Device.PermissionDeniedByPolicy") {
+            if (callPrivilegedMount())
+              return;
+            // if we fail to run kdesu, fall through and emit the original PermissionDeniedByPolicy error
+        }
         m_setupInProgress = false;
         emit setupDone(Solid::UnauthorizedOperation,
                        QString(error.name()+": "+error.message()),
                        m_device->udi());
     } else if (m_teardownInProgress) {
+        if (error.name() == "org.freedesktop.Hal.Device.PermissionDeniedByPolicy") {
+            if (callPrivilegedUnmount())
+              return;
+            // if we fail to run kdesu, fall through and emit the original PermissionDeniedByPolicy error
+        }
         m_teardownInProgress = false;
         emit teardownDone(Solid::UnauthorizedOperation,
                           QString(error.name()+": "+error.message()),
                           m_device->udi());
     }
@@ -292,12 +304,13 @@
 #ifdef Q_OS_FREEBSD
     QString uid="-u=";
 #else
     QString uid="uid=";
 #endif
-    if (halOptions.contains(uid)) {
-        options << uid+QString::number(::getuid());
+    if (halOptions.contains(uid) &&
+       (fstype == "vfat" || fstype == "iso9660" || fstype == "hfs" || fstype == "udf")) {
+            options << uid+QString::number(::getuid());
     }
 
 #ifdef Q_OS_FREEBSD
     char *cType;
     if ( fstype=="vfat" && halOptions.contains("-L=")) {
@@ -335,10 +348,63 @@
     return c.callWithCallback(msg, this,
                               SLOT(slotDBusReply(const QDBusMessage &)),
                               SLOT(slotDBusError(const QDBusError &)));
 }
 
+bool Solid::Backends::Hal::StorageAccess::callPrivilegedMount()
+{
+    QString udi = m_device->udi();
+    QString options;
+    QStringList halOptions = m_device->property("volume.mount.valid_options").toStringList();
+    QString fstype = m_device->property("volume.fstype").toString();
+
+    if (halOptions.contains("uid=")
+        && (fstype == "vfat" || fstype == "iso9660" || fstype == "hfs" || fstype == "udf")) {
+        options = "uid="+QString::number(::getuid());
+    }
+
+    m_process = new QProcess(this);
+
+    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
+            this, SLOT(slotProcessFinished(int, QProcess::ExitStatus)));
+
+    m_process->start(LIBEXEC_INSTALL_DIR "/kdesu", QStringList() << "-d" << "-t"
+        << "--noignorebutton" << "-c"
+        << QString::fromLatin1("dbus-send  --system --print-reply --dest=org.freedesktop.Hal %1 "
+                               "org.freedesktop.Hal.Device.Volume.Mount string: string: "
+                               "array:string:%2").arg(udi).arg(options));
+
+    if (m_process->waitForStarted()) {
+        return true;
+    } else {
+        delete m_process;
+        return false;
+    }
+}
+
+bool Solid::Backends::Hal::StorageAccess::callPrivilegedUnmount()
+{
+    QString udi = m_device->udi();
+
+    m_process = new QProcess(this);
+
+    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
+            this, SLOT(slotProcessFinished(int, QProcess::ExitStatus)));
+
+    m_process->start(LIBEXEC_INSTALL_DIR "/kdesu", QStringList() << "-d" << "-t"
+        << "--noignorebutton" << "-c"
+        << QString::fromLatin1("dbus-send  --system --print-reply --dest=org.freedesktop.Hal %1 "
+                               "org.freedesktop.Hal.Device.Volume.Unmount array:string:").arg(udi));
+
+    if (m_process->waitForStarted()) {
+        return true;
+    } else {
+        delete m_process;
+        return false;
+    }
+}
+
 bool StorageAccess::callHalVolumeUnmount()
 {
     QDBusConnection c = QDBusConnection::systemBus();
     QString udi = m_device->udi();
     QDBusMessage msg = QDBusMessage::createMethodCall("org.freedesktop.Hal", udi,
Only in kdelibs-4.3.75svn1048496.polkit/solid/solid/backends/hal: halstorageaccess.cpp.orig
diff -r -U5 kdelibs-4.3.75svn1048496/solid/solid/backends/hal/halstorageaccess.h kdelibs-4.3.75svn1048496.polkit/solid/solid/backends/hal/halstorageaccess.h
--- kdelibs-4.3.75svn1048496/solid/solid/backends/hal/halstorageaccess.h	2008-05-21 07:07:38.000000000 -0400
+++ kdelibs-4.3.75svn1048496.polkit/solid/solid/backends/hal/halstorageaccess.h	2009-11-20 14:38:17.000000000 -0500
@@ -67,10 +67,13 @@
     bool callHalVolumeUnmount();
 
     bool callSystemMount();
     bool callSystemUnmount();
 
+    bool callPrivilegedMount();
+    bool callPrivilegedUnmount();
+
     bool requestPassphrase();
     void callCryptoSetup(const QString &passphrase);
     bool callCryptoTeardown();
 
 private:


Index: .cvsignore
===================================================================
RCS file: /cvs/pkgs/rpms/kdelibs/devel/.cvsignore,v
retrieving revision 1.82
retrieving revision 1.83
diff -u -p -r1.82 -r1.83
--- .cvsignore	31 Oct 2009 13:10:42 -0000	1.82
+++ .cvsignore	24 Nov 2009 15:24:36 -0000	1.83
@@ -1 +1 @@
-kdelibs-4.3.3.tar.bz2
+kdelibs-4.3.75svn1048496.tar.bz2


Index: kdelibs.spec
===================================================================
RCS file: /cvs/pkgs/rpms/kdelibs/devel/kdelibs.spec,v
retrieving revision 1.536
retrieving revision 1.537
diff -u -p -r1.536 -r1.537
--- kdelibs.spec	21 Nov 2009 23:56:37 -0000	1.536
+++ kdelibs.spec	24 Nov 2009 15:24:37 -0000	1.537
@@ -1,14 +1,15 @@
 %define phonon_ver 4.3.1
 %define soprano_ver 2.3.0
 %define strigi_ver 0.7
+%define alphatag svn1048496
 
 %if 0%{?fedora} > 11
 %define soprano_ver 2.3.1
 %endif
 
 Summary: K Desktop Environment 4 - Libraries
-Version: 4.3.3
-Release: 6%{?dist}
+Version: 4.3.75
+Release: 0.1.%{alphatag}%{?dist}
 
 Name: kdelibs
 Epoch: 6
@@ -20,7 +21,7 @@ Provides:  kdelibs4 = %{version}-%{relea
 License: LGPLv2+
 URL:     http://www.kde.org/
 Group:   System Environment/Libraries
-Source0: ftp://ftp.kde.org/pub/kde/stable/%{version}/src/kdelibs-%{version}.tar.bz2
+Source0: ftp://ftp.kde.org/pub/kde/unstable/%{version}/src/kdelibs-%{version}%{?alphatag}.tar.bz2
 BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
 
 %ifarch noarch
@@ -51,7 +52,7 @@ Source1: kde4.sh
 Source2: kde4.csh
 
 # make -devel packages parallel-installable
-Patch0: kdelibs-4.2.96-parallel_devel.patch
+Patch0: kdelibs-4.3.75-parallel_devel.patch
 # fix kde#149705
 Patch2: kdelibs-4.2.85-kde149705.patch
 # Hunspell support for K3Spell
@@ -69,19 +70,14 @@ Patch9: kdelibs-4.0.2-branding.patch
 # are loaded from kde4rc
 Patch10: kdelibs-4.1.72-no-cache-kdeglobals-paths.patch
 # workaround for policykit
-Patch11: kdelibs-4.1.72-policykit-workaround.patch
+Patch11: kdelibs-4.3.75-policykit-workaround.patch
 Patch12: kdelibs-4.1.0-xdg-menu.patch
 # patch KStandardDirs to use %{_libexecdir}/kde4 instead of %{_libdir}/kde4/libexec
 Patch14: kdelibs-4.2.85-libexecdir.patch
 # kstandarddirs changes: search /etc/kde, find /usr/libexec/kde4
 Patch18: kdelibs-4.1.72-kstandarddirs.patch
 Patch20: kdelibs-4.1.70-cmake.patch
-Patch21: kdelibs-4.3.1-ossl-1.x.patch
-# patch to fix keditbookmarks crash (kde#160679)
-Patch22: kdelibs-4.3.0-bookmarks.patch
 Patch24: kdelibs-4.3.1-drkonq.patch
-# fix build of fakes.c due to missing #include <string.h>
-Patch25: kdelibs-4.3.3-fix-kdefakes-build.patch
 # use -fno-var-tracking-assignments on khtml/svg bits, use in a pinch on f12+
 # workaound for low-mem systems (ppc64), tracking here (for now),
 # https://bugzilla.redhat.com/show_bug.cgi?id=539697
@@ -90,10 +86,6 @@ Patch26: kdelibs-4.3.3-khtml_svg_no_var_
 # upstream
 # kubuntu working to upstream this
 Patch50: http://bazaar.launchpad.net/~kubuntu-members/kdelibs/ubuntu/download/head:/kubuntu_80_kaction_q-20091014221915-y11xctvidhr0ewmz-1/kubuntu_80_kaction_qt_keys.diff
-# 4.4 trunk
-# http://websvn.kde.org/?view=revision&revision=1027234
-# add adFilteredBy API required for konq-plugins-4.3.3 to build
-Patch100: kdelibs-4.3.3-adFilteredBy.patch
 
 # security fix
 Patch200: kdelibs-4.3.1-CVE-2009-2702.patch
@@ -115,8 +107,6 @@ BuildRequires: enchant-devel
 BuildRequires: gamin-devel
 BuildRequires: gettext-devel
 BuildRequires: giflib-devel
-# busted at least on x86_64
-#BuildRequires: hspell-devel
 BuildRequires: jasper-devel
 BuildRequires: krb5-devel
 BuildRequires: libacl-devel libattr-devel
@@ -129,6 +119,9 @@ BuildRequires: OpenEXR-devel
 BuildRequires: openssl-devel
 BuildRequires: pcre-devel
 BuildRequires: phonon-devel >= %{phonon_ver} 
+# TODO: polkit-qt dependency
+#BuildRequires: polkit-qt-devel >= %{polkit_qt_ver}
+BuildRequires: qca2-devel
 BuildRequires: shared-mime-info
 BuildRequires: soprano-devel >= %{soprano_ver} 
 BuildRequires: strigi-devel >= %{strigi_ver} 
@@ -149,6 +142,9 @@ BuildRequires: qt4-doc
 Provides: kross(javascript) = %{version}-%{release}
 Provides: kross(qtscript) = %{version}-%{release}
 
+Provides: kdelibs-experimental = %{version}-%{release}
+Obsoletes: kdelibs-experimental < %{version}-%{release}
+
 %description
 Libraries for the K Desktop Environment 4.
 
@@ -168,6 +164,8 @@ Provides: plasma-devel = %{version}-%{re
 Requires: %{name} = %{?epoch:%{epoch}:}%{version}-%{release}
 Obsoletes: kdelibs4-devel < %{version}-%{release}
 Provides:  kdelibs4-devel = %{version}-%{release}
+Obsoletes: kdelibs-experimental-devel < %{version}-%{release}
+Provides:  kdelibs-experimental-devel = %{version}-%{release}
 Requires: cmake >= 2.6.2-3
 Requires: automoc4 >= 0.9.88
 Requires: qt4-devel
@@ -177,6 +175,10 @@ Requires: phonon-devel
 Requires: strigi-devel
 Requires: bzip2-devel gamin-devel libacl-devel
 %{?x_deps:Requires: %{x_deps}}
+
+Provides: kdelibs-experimental-devel = %{version}-%{release}
+Obsoletes: kdelibs-experimental-devel < %{version}-%{release}
+
 %description devel
 This package includes the header files you will need to compile
 applications for KDE 4.
@@ -195,7 +197,7 @@ format for easy browsing.
 
 
 %prep
-%setup -q -n kdelibs-%{version}
+%setup -q -n kdelibs-%{version}%{?alphatag}
 
 %patch0 -p1 -b .parallel_devel
 %patch2 -p1 -b .kde149705
@@ -207,20 +209,13 @@ format for easy browsing.
 %patch14 -p1 -b .libexecdir
 %patch18 -p1 -b .kstandarddirs
 %patch20 -p1 -b .xxcmake
-%patch21 -p1 -b .ossl-1.x
-%patch22 -p1 -b .bookmarks
 %if 0%{?rhel} > 5
 %patch24 -p1 -b .drkonq
 %endif
-%patch25 -p1 -b .fix-kdefakes-build
-%ifarch ppc64
 %patch26 -p1 -b .khtml_svg_no_var_tracking_assignments
-%endif
 
 # upstream patches
 %patch50 -p1 -b .kaction_qt_keys
-# 4.4
-%patch100 -p0 -b .adFilteredBy
 
 # security fix
 %patch200 -p1 -b .CVE-2009-2702
@@ -348,6 +343,8 @@ rm -rf %{buildroot}
 %exclude %{_kde4_appsdir}/cmake/
 %{_kde4_configdir}/*
 %{_datadir}/dbus-1/interfaces/*
+%{_datadir}/dbus-1/system-services/*
+%{_sysconfdir}/dbus-1/system.d/*
 %{_kde4_datadir}/mime/packages/kde.xml
 %{_kde4_sharedir}/kde4/services/*
 %{_kde4_sharedir}/kde4/servicetypes/*
@@ -413,6 +410,9 @@ rm -rf %{buildroot}
 
 
 %changelog
+* Fri Nov 20 2009 Ben Boeckel <MathStuf at gmail.com> - 4.3.75-0.1.svn1048496
+- Update to 4.3.75 snapshot
+
 * Wed Nov 18 2009 Rex Dieter <rdieter at fedoraproject.org> - 4.3.3-6
 - rebuild (for qt-4.6.0-rc1, f13+)
 - fix/revert soprano_ver change in -5


Index: sources
===================================================================
RCS file: /cvs/pkgs/rpms/kdelibs/devel/sources,v
retrieving revision 1.97
retrieving revision 1.98
diff -u -p -r1.97 -r1.98
--- sources	31 Oct 2009 13:10:43 -0000	1.97
+++ sources	24 Nov 2009 15:24:37 -0000	1.98
@@ -1 +1 @@
-20fd3793d9d23088ecb1d5aed0254216  kdelibs-4.3.3.tar.bz2
+d8b84a20332c30256c431203b962bad9  kdelibs-4.3.75svn1048496.tar.bz2


--- kdelibs-4.1.72-policykit-workaround.patch DELETED ---


--- kdelibs-4.2.96-parallel_devel.patch DELETED ---


--- kdelibs-4.3.0-bookmarks.patch DELETED ---


--- kdelibs-4.3.1-ossl-1.x.patch DELETED ---


--- kdelibs-4.3.3-adFilteredBy.patch DELETED ---


--- kdelibs-4.3.3-fix-kdefakes-build.patch DELETED ---




More information about the fedora-extras-commits mailing list
diff -r -U5 kdelibs-4.3.75svn1048496/cmake/modules/FindKDE4Internal.cmake kdelibs-4.3.75svn1048496.parallel_devel/cmake/modules/FindKDE4Internal.cmake
--- kdelibs-4.3.75svn1048496/cmake/modules/FindKDE4Internal.cmake	2009-11-13 05:58:59.000000000 -0500
+++ kdelibs-4.3.75svn1048496.parallel_devel/cmake/modules/FindKDE4Internal.cmake	2009-11-23 10:34:21.000000000 -0500
@@ -13,14 +13,14 @@
 #                             intended to be used with LINK_DIRECTORIES()
 #
 # The following variables are defined for the various tools required to
 # compile KDE software:
 #
-#  KDE4_KCFGC_EXECUTABLE    - the kconfig_compiler executable
+#  KDE4_KCFGC_EXECUTABLE    - the kconfig_compiler4 executable
 #  KDE4_AUTOMOC_EXECUTABLE  - the kde4automoc executable, deprecated, use AUTOMOC4_EXECUTABLE instead
 #  KDE4_MEINPROC_EXECUTABLE - the meinproc4 executable
-#  KDE4_MAKEKDEWIDGETS_EXECUTABLE - the makekdewidgets executable
+#  KDE4_MAKEKDEWIDGETS_EXECUTABLE - the makekdewidgets4 executable
 #
 # The following variables point to the location of the KDE libraries,
 # but shouldn't be used directly:
 #
 #  KDE4_KDECORE_LIBRARY     - the kdecore library
@@ -134,11 +134,11 @@
 #    Use optional GENERATE_MOC to generate moc if you use signals in your kcfg files.
 #    Use optional USE_RELATIVE_PATH to generate the classes in the build following the given
 #    relative path to the file.
 #
 #  KDE4_ADD_WIDGET_FILES (SRCS_VAR file1.widgets ... fileN.widgets)
 #    Use this to add widget description files for the makekdewidgets code generator
 #    for Qt Designer plugins.
 #
 #  KDE4_CREATE_FINAL_FILES (filename_CXX filename_C file1 ... fileN)
 #    This macro is intended mainly for internal uses.
 #    It is used for enable-final. It will generate two source files,
@@ -421,29 +421,29 @@
    set(EXECUTABLE_OUTPUT_PATH ${kdelibs_BINARY_DIR}/bin )
 
    if (WIN32)
       set(LIBRARY_OUTPUT_PATH               ${EXECUTABLE_OUTPUT_PATH} )
       # CMAKE_CFG_INTDIR is the output subdirectory created e.g. by XCode and MSVC
-      set(KDE4_KCFGC_EXECUTABLE             ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler )
+      set(KDE4_KCFGC_EXECUTABLE             ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler4 )
 
       set(KDE4_MEINPROC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc4 )
       set(KDE4_KAUTH_POLICY_GEN_EXECUTABLE  ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kauth-policy-gen )
-      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE    ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets )
+      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE    ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets4 )
    else (WIN32)
       set(LIBRARY_OUTPUT_PATH               ${CMAKE_BINARY_DIR}/lib )
-      set(KDE4_KCFGC_EXECUTABLE             ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler${CMAKE_EXECUTABLE_SUFFIX}.shell )
+      set(KDE4_KCFGC_EXECUTABLE             ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler4${CMAKE_EXECUTABLE_SUFFIX}.shell )
       set(KDE4_KAUTH_POLICY_GEN_EXECUTABLE  ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kauth-policy-gen${CMAKE_EXECUTABLE_SUFFIX}.shell )
       set(KDE4_MEINPROC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc4${CMAKE_EXECUTABLE_SUFFIX}.shell )
-      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE    ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets${CMAKE_EXECUTABLE_SUFFIX}.shell )
+      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE    ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets4${CMAKE_EXECUTABLE_SUFFIX}.shell )
    endif (WIN32)
 
    set(KDE4_LIB_DIR ${LIBRARY_OUTPUT_PATH}/${CMAKE_CFG_INTDIR})
 
    # when building kdelibs, make the kcfg rules depend on the binaries...
-   set( _KDE4_KCONFIG_COMPILER_DEP kconfig_compiler)
+   set( _KDE4_KCONFIG_COMPILER_DEP kconfig_compiler4)
    set( _KDE4_KAUTH_POLICY_GEN_EXECUTABLE_DEP kauth-policy-gen)
-   set( _KDE4_MAKEKDEWIDGETS_DEP makekdewidgets)
+   set( _KDE4_MAKEKDEWIDGETS_DEP makekdewidgets4)
    set( _KDE4_MEINPROC_EXECUTABLE_DEP meinproc4)
 
    set(KDE4_INSTALLED_VERSION_OK TRUE)
 
 else (_kdeBootStrapping)
@@ -540,11 +540,12 @@
    # and this one for compatibility:
    set(KDE4_THREADWEAVER_LIBRARIES ${KDE4_TARGET_PREFIX}threadweaver )
 
    # KDE4_LIB_INSTALL_DIR and KDE4_INCLUDE_INSTALL_DIR are set in KDELibsDependencies.cmake,
    # use them to set the KDE4_LIB_DIR and KDE4_INCLUDE_DIR "public interface" variables
-   set(KDE4_LIB_DIR ${KDE4_LIB_INSTALL_DIR} )
+   set(KDE4_LIB_DIR ${KDE4_LIB_INSTALL_DIR}/kde4/devel )
+   link_directories("${KDE4_LIB_DIR}")
    set(KDE4_INCLUDE_DIR ${KDE4_INCLUDE_INSTALL_DIR} )
 
 
    # This setting is currently not recorded in KDELibsDependencies.cmake:
    find_file(KDE4_PLASMA_OPENGL_FOUND plasma/glapplet.h PATHS ${KDE4_INCLUDE_DIR} NO_DEFAULT_PATH)
@@ -556,14 +557,14 @@
    # get the build CONFIGURATIONS which were exported in this file, and use just the first
    # of them to get the location of the installed executables
    get_target_property(_importedConfigurations  ${KDE4_TARGET_PREFIX}kconfig_compiler IMPORTED_CONFIGURATIONS )
    list(GET _importedConfigurations 0 _firstConfig)
 
-   get_target_property(KDE4_KCFGC_EXECUTABLE             ${KDE4_TARGET_PREFIX}kconfig_compiler    LOCATION_${_firstConfig})
+   get_target_property(KDE4_KCFGC_EXECUTABLE             ${KDE4_TARGET_PREFIX}kconfig_compiler4    LOCATION_${_firstConfig})
    get_target_property(KDE4_MEINPROC_EXECUTABLE          ${KDE4_TARGET_PREFIX}meinproc4           LOCATION_${_firstConfig})
    get_target_property(KDE4_KAUTH_POLICY_GEN_EXECUTABLE  ${KDE4_TARGET_PREFIX}kauth-policy-gen    LOCATION_${_firstConfig})
-   get_target_property(KDE4_MAKEKDEWIDGETS_EXECUTABLE    ${KDE4_TARGET_PREFIX}makekdewidgets      LOCATION_${_firstConfig})
+   get_target_property(KDE4_MAKEKDEWIDGETS_EXECUTABLE    ${KDE4_TARGET_PREFIX}makekdewidgets4      LOCATION_${_firstConfig})
 
    # allow searching cmake modules in all given kde install locations (KDEDIRS based)
    execute_process(COMMAND "${KDE4_KDECONFIG_EXECUTABLE}" --path data OUTPUT_VARIABLE _data_DIR ERROR_QUIET OUTPUT_STRIP_TRAILING_WHITESPACE)
    file(TO_CMAKE_PATH "${_data_DIR}" _data_DIR)
    foreach(dir ${_data_DIR})
@@ -828,11 +829,12 @@
                               "${KDE4_INCLUDE_INSTALL_DIR}")
 
 set(CMAKE_SYSTEM_PROGRAM_PATH ${CMAKE_SYSTEM_PROGRAM_PATH}
                               "${KDE4_BIN_INSTALL_DIR}" )
 
-set(CMAKE_SYSTEM_LIBRARY_PATH ${CMAKE_SYSTEM_LIBRARY_PATH}
+set(CMAKE_SYSTEM_LIBRARY_PATH "${KDE4_LIB_INSTALL_DIR}/kde4/devel"
+                              ${CMAKE_SYSTEM_LIBRARY_PATH}
                               "${KDE4_LIB_INSTALL_DIR}" )
 
 # under Windows dlls may be also installed in bin/
 if(WIN32)
   set(CMAKE_SYSTEM_LIBRARY_PATH ${CMAKE_SYSTEM_LIBRARY_PATH}
@@ -1217,13 +1219,13 @@
           message(STATUS "ERROR: unable to find the KDE 4 core library")
        endif(KDE4_LIB_DIR)
    endif (NOT _kdeBootStrapping)
 
    if(KDE4_KCFGC_EXECUTABLE)
-      message(STATUS "Found the KDE4 kconfig_compiler preprocessor: ${KDE4_KCFGC_EXECUTABLE}")
+      message(STATUS "Found the KDE4 kconfig_compiler4 preprocessor: ${KDE4_KCFGC_EXECUTABLE}")
    else(KDE4_KCFGC_EXECUTABLE)
-      message(STATUS "Didn't find the KDE4 kconfig_compiler preprocessor")
+      message(STATUS "Didn't find the KDE4 kconfig_compiler4 preprocessor")
    endif(KDE4_KCFGC_EXECUTABLE)
 
    if(AUTOMOC4_EXECUTABLE)
       message(STATUS "Found automoc4: ${AUTOMOC4_EXECUTABLE}")
    else(AUTOMOC4_EXECUTABLE)
@@ -1238,11 +1240,11 @@
    if (NOT KDE4_INSTALLED_VERSION_OK)
      message(FATAL_ERROR "ERROR: the installed kdelibs version ${KDE_VERSION} is too old, at least version ${KDE_MIN_VERSION} is required")
    endif (NOT KDE4_INSTALLED_VERSION_OK)
 
    if (NOT KDE4_KCFGC_EXECUTABLE)
-     message(FATAL_ERROR "ERROR: could not detect a usable kconfig_compiler")
+     message(FATAL_ERROR "ERROR: could not detect a usable kconfig_compiler4")
    endif (NOT KDE4_KCFGC_EXECUTABLE)
 
    message(FATAL_ERROR "ERROR: could NOT find everything required for compiling KDE 4 programs")
@@ -134,11 +134,11 @@
 #
 #  KDE4_ADD_WIDGET_FILES (SRCS_VAR file1.widgets ... fileN.widgets)
-#    Use this to add widget description files for the makekdewidgets code generator
+#    Use this to add widget description files for the makekdewidgets4 code generator
 #    for Qt Designer plugins.
 #
 endif (KDE4Internal_FIND_REQUIRED AND NOT KDE4_FOUND)
 